export interface BookingsAppSettings {
    /**
     * Revision number, which increments by 1 each time the BookingsAppSettings is updated.
     * To prevent conflicting changes,
     * the current revision must be passed when updating the BookingsAppSettings.
     *
     * Ignored when creating a BookingsAppSettings.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the BookingsAppSettings was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the BookingsAppSettings was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** Cart checkout settings */
    cartCheckoutSettings?: CartCheckoutSettings;
    /** Multi service appointment settings */
    multiServicesAppointmentsSettings?: MultiServicesAppointmentsSettings;
    /** Client time zone settings */
    clientTimeZoneSettings?: ClientTimeZoneSettings;
    /**
     * Site properties. Will return null if there is a failure fetching site properties
     * @readonly
     */
    siteProperties?: SiteProperties;
    /**
     * Bookings features. Will return null if there is a failure fetching bookings features
     * @readonly
     */
    features?: Features;
}
export interface CartCheckoutSettings {
    /** Whether the cart checkout feature is enabled */
    enabled?: boolean | null;
}
export interface MultiServicesAppointmentsSettings {
    /** Whether the multi service appointments feature is enabled */
    enabled?: boolean | null;
}
export interface ClientTimeZoneSettings {
    /** gives the client ability to change the time zone source between business and client */
    canClientChangeTimeZoneSource?: boolean | null;
    /** default_time_zone can be either client or business */
    timeZoneSource?: TimeZoneSource;
}
export declare enum TimeZoneSource {
    /** Business time zone source. */
    BUSINESS = "BUSINESS",
    /** Client time zone source. */
    CLIENT = "CLIENT"
}
export interface SiteProperties {
    /** Selected locale. */
    locale?: Locale;
    /**
     * Selected language code (ISO 639-1).
     * @format LANGUAGE
     */
    language?: string | null;
    /**
     * Selected currency code (ISO 4217) to bill customers of this site.
     * @format CURRENCY
     */
    paymentCurrency?: string | null;
    /**
     * Time zone.
     * @maxLength 255
     */
    timeZone?: string | null;
    /**
     * Publicly-available business email address.
     * @format EMAIL
     */
    email?: string | null;
    /**
     * Publicly-available business phone number.
     * @format PHONE
     */
    phone?: string | null;
    /** Publicly-available business address. */
    address?: Address;
    /**
     * Site display name.
     * @maxLength 255
     */
    siteDisplayName?: string | null;
    /**
     * Business name.
     * @maxLength 255
     */
    businessName?: string | null;
}
export interface Locale {
    /**
     * Language code (ISO 639-1).
     * @format LANGUAGE
     */
    languageCode?: string;
    /**
     * Country code (ISO 3166-1).
     * @format COUNTRY
     */
    country?: string;
}
export interface Address {
    /**
     * Street name.
     * @maxLength 255
     */
    street?: string;
    /**
     * City.
     * @maxLength 255
     */
    city?: string;
    /**
     * Country code (2 alphanumeric characters per ISO 3166-1).
     * @maxLength 255
     */
    country?: string;
    /**
     * State (if applicable).
     * @maxLength 255
     */
    state?: string;
    /**
     * Zip code.
     * @maxLength 255
     */
    zip?: string;
    /** Extra information to be displayed in the address. */
    hint?: AddressHint;
    /** Whether this address represents a physical location. */
    physical?: boolean;
    /**
     * A Google-formatted version of this address (acceptable to most APIs).
     * @maxLength 255
     */
    googleFormattedAddress?: string;
    /**
     * Street number.
     * @maxLength 255
     */
    streetNumber?: string;
    /**
     * Apartment number (if applicable).
     * @maxLength 255
     */
    apartmentNumber?: string;
    /** Geocoordinates. */
    coordinates?: GeoCoordinates;
}
/**
 * Extra information on displayed addresses.
 * This is used for display purposes. Used to add additional data about the address, such as "In the passage".
 * Free text. In addition the user can state where he wants that additional description - before, after, or instead
 * the address string.
 */
export interface AddressHint {
    /**
     * Extra text displayed next to, or instead of, the actual address.
     * @maxLength 255
     */
    text?: string;
    /** Where the extra text should be displayed. */
    placement?: PlacementType;
}
/** Where the extra text should be displayed: before, after or instead of the actual address. */
export declare enum PlacementType {
    BEFORE = "BEFORE",
    AFTER = "AFTER",
    REPLACE = "REPLACE"
}
/** Geocoordinates for a particular address. */
export interface GeoCoordinates {
    /** Latitude. */
    latitude?: number;
    /** Longitude. */
    longitude?: number;
}
export interface Features {
    /** `bookings_service_list` feature */
    bookingsServiceList?: Feature;
    /** `bookings_payments` feature */
    bookingsPayments?: Feature;
    /** `bookings_groups` feature */
    bookingsGroups?: Feature;
    /** `bookings_reminders` feature */
    bookingsReminders?: Feature;
    /** `bookings_courses` feature */
    bookingsCourses?: Feature;
    /** `bookings_appointments` feature */
    bookingsAppointments?: Feature;
    /** `bookings_sms_reminders` feature */
    bookingsSmsReminders?: Feature;
    /** `bookings_external_calendars` feature */
    bookingsExternalCalendars?: Feature;
    /** `bookings_staff_limit` feature */
    bookingsStaffLimit?: Feature;
    /** `anywhere_bookings_service_limit` feature */
    anywhereBookingsServiceLimit?: Feature;
    /** `anywhere_bookings_staff_limit` feature */
    anywhereBookingsStaffLimit?: Feature;
    /** `anywhere_remove_brand` feature */
    anywhereRemoveBrand?: Feature;
    /** `anywhere_customization_widget` feature */
    anywhereCustomizationWidget?: Feature;
    /** `bookings_video_conferencing` feature */
    bookingsVideoConferencing?: Feature;
    /** `accept_payments` feature */
    acceptPayments?: Feature;
}
export interface Feature {
    /** true if feature is enabled */
    enabled?: boolean;
    /** limit for the feature quota. null if no limit exists for the feature */
    quotaLimit?: string | null;
}
export interface CreateBookingsAppSettingsRequest {
    /** BookingsAppSettings to be created. */
    bookingsAppSettings: BookingsAppSettings;
    /**
     * The requested fields.
     * @maxSize 2
     */
    fields?: RequestedFields[];
}
export declare enum RequestedFields {
    SITE_PROPERTIES = "SITE_PROPERTIES",
    FEATURES = "FEATURES"
}
export interface CreateBookingsAppSettingsResponse {
    /** The created BookingsAppSettings. */
    bookingsAppSettings?: BookingsAppSettings;
}
export interface GetBookingsAppSettingsRequest {
    /**
     * The requested fields.
     * @maxSize 2
     */
    fields?: RequestedFields[];
}
export interface GetBookingsAppSettingsResponse {
    /** The requested BookingsAppSettings. */
    bookingsAppSettings?: BookingsAppSettings;
}
export interface UpdateBookingsAppSettingsRequest {
    /** BookingsAppSettings to be updated, may be partial. */
    bookingsAppSettings: BookingsAppSettings;
    /**
     * The requested fields.
     * @maxSize 2
     */
    fields?: RequestedFields[];
}
export interface UpdateBookingsAppSettingsResponse {
    /** Updated BookingsAppSettings. */
    bookingsAppSettings?: BookingsAppSettings;
}
export interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /**
     * Unique event ID.
     * Allows clients to ignore duplicate webhooks.
     */
    id?: string;
    /**
     * Assumes actions are also always typed to an entity_type
     * Example: wix.stores.catalog.product, wix.bookings.session, wix.payments.transaction
     */
    entityFqdn?: string;
    /**
     * This is top level to ease client code dispatching of messages (switch on entity_fqdn+slug)
     * This is although the created/updated/deleted notion is duplication of the oneof types
     * Example: created/updated/deleted/started/completed/email_opened
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example: 2020-04-26T13:57:50.699Z */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number defining the order of updates to the underlying entity.
     * For example, given that some entity was updated at 16:00 and than again at 16:01,
     * it is guaranteed that the sequence number of the second update is strictly higher than the first.
     * As the consumer, you can use this value to ensure that you handle messages in the correct order.
     * To do so, you will need to persist this number on your end, and compare the sequence number from the
     * message against the one you have stored. Given that the stored number is higher, you should ignore the message.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
export interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
export interface EntityCreatedEvent {
    entityAsJson?: string;
    /** Indicates the event was triggered by a restore-from-trashbin operation for a previously deleted entity */
    restoreInfo?: RestoreInfo;
}
export interface RestoreInfo {
    deletedDate?: Date | null;
}
export interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntityAsJson?: string;
}
export interface EntityDeletedEvent {
    /** Entity that was deleted */
    deletedEntityAsJson?: string | null;
}
export interface ActionEvent {
    bodyAsJson?: string;
}
export interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
export interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityType;
}
/** @oneof */
export interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
export declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
interface ClientTimeZoneSettingsNonNullableFields {
    timeZoneSource: TimeZoneSource;
}
interface LocaleNonNullableFields {
    languageCode: string;
    country: string;
}
interface AddressHintNonNullableFields {
    text: string;
    placement: PlacementType;
}
interface GeoCoordinatesNonNullableFields {
    latitude: number;
    longitude: number;
}
interface AddressNonNullableFields {
    street: string;
    city: string;
    country: string;
    state: string;
    zip: string;
    hint?: AddressHintNonNullableFields;
    physical: boolean;
    googleFormattedAddress: string;
    streetNumber: string;
    apartmentNumber: string;
    coordinates?: GeoCoordinatesNonNullableFields;
}
interface SitePropertiesNonNullableFields {
    locale?: LocaleNonNullableFields;
    address?: AddressNonNullableFields;
}
interface FeatureNonNullableFields {
    enabled: boolean;
}
interface FeaturesNonNullableFields {
    bookingsServiceList?: FeatureNonNullableFields;
    bookingsPayments?: FeatureNonNullableFields;
    bookingsGroups?: FeatureNonNullableFields;
    bookingsReminders?: FeatureNonNullableFields;
    bookingsCourses?: FeatureNonNullableFields;
    bookingsAppointments?: FeatureNonNullableFields;
    bookingsSmsReminders?: FeatureNonNullableFields;
    bookingsExternalCalendars?: FeatureNonNullableFields;
    bookingsStaffLimit?: FeatureNonNullableFields;
    anywhereBookingsServiceLimit?: FeatureNonNullableFields;
    anywhereBookingsStaffLimit?: FeatureNonNullableFields;
    anywhereRemoveBrand?: FeatureNonNullableFields;
    anywhereCustomizationWidget?: FeatureNonNullableFields;
    bookingsVideoConferencing?: FeatureNonNullableFields;
    acceptPayments?: FeatureNonNullableFields;
}
interface BookingsAppSettingsNonNullableFields {
    clientTimeZoneSettings?: ClientTimeZoneSettingsNonNullableFields;
    siteProperties?: SitePropertiesNonNullableFields;
    features?: FeaturesNonNullableFields;
}
export interface CreateBookingsAppSettingsResponseNonNullableFields {
    bookingsAppSettings?: BookingsAppSettingsNonNullableFields;
}
export interface GetBookingsAppSettingsResponseNonNullableFields {
    bookingsAppSettings?: BookingsAppSettingsNonNullableFields;
}
export interface UpdateBookingsAppSettingsResponseNonNullableFields {
    bookingsAppSettings?: BookingsAppSettingsNonNullableFields;
}
export {};
